# ewoksweb

_ewoksweb_ is a frontend to create, visualize and execute
[ewoks](https://ewoks.readthedocs.io/) workflows in the web.

## Demo

https://workflow.gitlab-pages.esrf.fr/ewoks/ewoksweb/

## Local installation

Install the [ewoksserver](https://ewoksserver.readthedocs.io) python package

```bash
pip install ewoksserver[frontend]
```

Start the server and open the frontend in a web browser

```bash
ewoks-server
```

## Documentation

https://ewoksweb.readthedocs.io/
